@@ -1,53 +1,38 @@
-import contextlib
-import io
+import functools
+import gzip
 import os
 import re
 import shutil
+import zipfile
 
 
-@contextlib.contextmanager
-def open_on_zip(zip_file, filename):
-    """
-    Open a file that is inside a zip file.
-
-    :param zip_file: instance of ZipFile class
-    :param str filename:
-
-    Examples:
-    -------------------------------------------------
-    import zipfile
-    from pymince.file import open_on_zip
-
-    with zipfile.ZipFile(zip_filename) as zf:
-        # example1
-        with open_on_zip(zf, "foo1.txt") as fd1:
-            foo1_string = fd1.read()
-        # example2
-        with open_on_zip(zf, "foo2.txt") as fd2:
-            foo2_string = fd2.read()
-    -------------------------------------------------
-    """
-    with zip_file.open(filename) as fd:
-        yield io.TextIOWrapper(fd, encoding="utf-8")
-
-
-def match_on_zip(zip_file, pattern):
+def match_from_zip(zip_file, pattern):
     """
     Make an iterator that returns file names in the zip file that
     match the given pattern.
     Uppercase/lowercase letters are ignored.
 
-    :param zip_file: instance of ZipFile class
+    :param zip_file: ZipFile object or zip path.
     :param pattern: "re.Pattern" to filter filename list
     :return: Iterator with the filenames found
 
     Examples:
         import pymince.file
-        pymince.file.match_on_zip(zip_file, "^file") # --> file1.log file2.txt
-
+        pymince.file.match_from_zip("archive.zip", "^file") # --> file1.log file2.txt
+        pymince.file.match_from_zip(zipfile.ZipFile("archive.zip"), "^file") # --> file1.log file2.txt
     """
-    matcher = re.compile(pattern, re.IGNORECASE).match
-    return iter(filter(matcher, zip_file.namelist()))
+
+    def match(file):
+        apply = re.compile(pattern, re.IGNORECASE).match
+        return iter(filter(apply, file.namelist()))
+
+    if isinstance(zip_file, zipfile.ZipFile):
+        return match(zip_file)
+    elif isinstance(zip_file, str):
+        with zipfile.ZipFile(zip_file) as zf:
+            return match(zf)
+    else:
+        raise ValueError(zip_file)
 
 
 def ensure_directory(path, cleaning=False):
@@ -113,3 +98,24 @@ def replace_extension(filename, old_ext=None, new_ext=None):
         return root + (new_ext or "")
     else:
         return filename
+
+
+def decompress(src_path, dst_path):
+    """
+    Decompress given file in blocks using gzip.
+
+    :param str src_path: source file path
+    :param str dst_path: destination file(unzipped) path
+    :return: dst_path
+
+     Examples:
+        from pymince.file import decompress
+
+        decompress("/foo/src.txt.gz", "/baz/dst.txt") # --> "/baz/dst.txt"
+    """
+
+    with gzip.open(src_path) as src:
+        with open(dst_path, 'wb') as dst:
+            lines = iter(functools.partial(src.read, 64 * 1024), b'')
+            dst.writelines(lines)
+    return dst_path
